@@ -3,7 +3,7 @@ package HTML::FormBuilder;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp;
 use HTML::FormBuilder::FieldSet;
@@ -47,25 +47,11 @@ sub BUILDARGS {
     my %args = (@args % 2) ? %{$args[0]} : @args;
 
     # set default class
-    my @class_names = qw( fieldset_group
-        no_stack_field_parent
-        row_padding
-        fieldset_footer
-        comment
-        row
-        extra_tooltip_container
-        backbutton
-        required_asterisk
-        inputtrailing
-        label_column
-        input_column
-        hide_mobile
-    );
-
-    my %classes = map { $_ => $_ } @class_names;
-    %classes = (%classes, %{$args{classes} || {}});
-
-    $args{classes} = \%classes;
+    if ($args{classes}) {
+        $args{classes} = {%{$HTML::FormBuilder::Base::CLASSES}, %{$args{classes}}};
+    } else {
+        $args{classes} = {%{$HTML::FormBuilder::Base::CLASSES}};
+    }
 
     $args{data}{method} ||= 'get';
     $args{data}{method} = 'get' if $args{data}{method} ne 'post';
@@ -466,7 +452,7 @@ HTML::FormBuilder - A Multi-part HTML form
     my $fieldset = $form->add_fieldset({id => 'fieldset1});
 
     #add field
-    $fieldset->({input => {name => 'name', type => 'text', value => 'Join'}});
+    $fieldset->add_field({input => {name => 'name', type => 'text', value => 'Join'}});
 
     #set field value
     $form->set_field_value('name', 'Omid');
@@ -494,7 +480,7 @@ The form attributes. It should be a hashref.
 
 =head2 classes
 
-The form classes. It should be a hashref. You can customize the form's layout by  the classes.
+The form classes. It should be a hashref. You can customize the form's layout by the classes.
 The class names used are:
 
       fieldset_group
@@ -528,7 +514,7 @@ The fieldsets the form have.
                 class => 'formclass'},
         classes => {row => 'rowdev'})
 
-The id is rquired for the form.
+The id is required for the form.
 
 =head2 add_fieldset
 
@@ -541,7 +527,7 @@ It will return the fielset object.
 
       $form->add_field(0, {input => {name => 'name', type => 'text', value => 'Join'}});
 
-The parameter is the fieldset index to which you want to add the filed and the field attributes.
+The parameter is the fieldset index to which you want to add the field and the field attributes.
 
 =head2 build
 
@@ -563,10 +549,10 @@ the data in the $form will be changed when build the form. So you cannot get the
                        'name'   => 'name_of_the_form',
                        'method' => 'post', # or get
                        'action' => 'page_to_submit',
-          					   'header' => 'My Form',
+                       'header' => 'My Form',
                        'localize' => $localize,
                        'classes'  => $classes,
-                       };	#header of the form
+                       };   #header of the form
   my $form = HTML::FormBuilder->new(data => $form_attributes, classes => $classes, localize => $localize);
 
   #Then create fieldset, the form is allow to have more than 1 fieldset
@@ -588,8 +574,8 @@ the data in the $form will be changed when build the form. So you cannot get the
   #The keys are label, input, error, comment
   #  Label define the title of the input field
   #  Input define and create the actual input type
-  #		In input fields, you can defined a key 'heading', which create a text before the input is displayed,
-  #		however, if the input type is radio the text is behind the radio box
+  #     In input fields, you can defined a key 'heading', which create a text before the input is displayed,
+  #     however, if the input type is radio the text is behind the radio box
   #  Error message that go together with the input field when fail in validation
   #  Comment is the message added to explain the input field.
 
@@ -599,19 +585,19 @@ the data in the $form will be changed when build the form. So you cannot get the
 
   my $input_text = {'label'   => {'text' => 'Register Name', for => 'name'},
                     'input'   => {'type' => 'text', 'value' => 'John', 'id' => 'name', 'name' => 'name', 'maxlength' => '22'},
-					'error'   => { 'id' => 'error_name' ,'text' => 'Name must be in alphanumeric', 'class' => 'errorfield hidden'},
-					'comment' => {'text' => 'Please tell us your name'}};
+                    'error'   => { 'id' => 'error_name' ,'text' => 'Name must be in alphanumeric', 'class' => 'errorfield hidden'},
+                    'comment' => {'text' => 'Please tell us your name'}};
 
   ####################################
   ###Creating a select option
   ####################################
-      my @options
-	  push @options, {'value' => 'Mr', 'text' => 'Mr'};
-	  push @options, {'value' => 'Mrs', 'text' => 'Mrs'};
+      my @options;
+      push @options, {'value' => 'Mr', 'text' => 'Mr'};
+      push @options, {'value' => 'Mrs', 'text' => 'Mrs'};
 
       my $input_select = {'label' => {'text' => 'Title', for => 'mrms'},
                           'input' => {'type' => 'select', 'id' => 'mrms', 'name' => 'mrms', 'options' => \@options},
-					                'error' => {'text' => 'Please select a title', 'class' => 'errorfield hidden'}};
+                          'error' => {'text' => 'Please select a title', 'class' => 'errorfield hidden'}};
 
 
   ####################################
@@ -635,7 +621,7 @@ the data in the $form will be changed when build the form. So you cannot get the
   my $input_select_dobyy = {'type' => 'select', 'id' => 'dobyy', 'name' => 'dobyy', 'options' => \@yyoptions};
   my $input_select = {'label' => {'text' => 'Birthday', for => 'dobdd'},
                       'input' => [$input_select_dobdd, $input_select_dobmm, $input_select_dobyy],
-			                'error' => {'text' => 'Invalid date.'}};
+                      'error' => {'text' => 'Invalid date.'}};
 
   #Then we add the input field into the Fieldset
   #You can add using index of the fieldset
@@ -669,43 +655,43 @@ the data in the $form will be changed when build the form. So you cannot get the
     <form id="onlineIDForm" method="post" action="">
        <fieldset id="fieldset_one" name="fieldset_one" class="formclass">
            <div>
-		   	    <label for="name">Register Name</label>
-				<em>:</em>
-				<input type="text" value="John" id="name" name="name">
-				<p id = "error_name" class="errorfield hidden">Name must be in alphanumeric</p>
-				<p>Please tell us your name</p>
-		   </div>
-		   <div>
-		   	    <label for="mrms">Title</label>
-				<em>:</em>
-				<select id="mrms" name="mrms">
-					<option value="Mr">Mr</option>
-					<option value="Mrs">Mrs</option>
-				</select>
-				<p class="errorfield hidden">Please select a title</p>
-		   </div>
-		   <div>
-		   	    <label for="dob">Birthday</label>
-				<em>:</em>
-				<select id="dobdd" name="dobdd">
-					<option value="1">1</option>
-					<option value="2">2</option>
-				</select>
-				<select id="dobmm" name="dobmm">
-					<option value="1">Jan</option>
-					<option value="2">Feb</option>
-				</select>
-				<select id="dobyy" name="dobyy">
-					<option value="1980">1980</option>
-					<option value="1981">1981</option>
-				</select>
-				<p class="errorfield hidden">Invalid date</p>
-		   </div>
-		   <div>
-		   		<input type="submit" value="Submit Form" id="submit" name="submit">
-		   </div>
+                <label for="name">Register Name</label>
+                <em>:</em>
+                <input type="text" value="John" id="name" name="name">
+                <p id = "error_name" class="errorfield hidden">Name must be in alphanumeric</p>
+                <p>Please tell us your name</p>
+           </div>
+           <div>
+                <label for="mrms">Title</label>
+                <em>:</em>
+                <select id="mrms" name="mrms">
+                    <option value="Mr">Mr</option>
+                    <option value="Mrs">Mrs</option>
+                </select>
+                <p class="errorfield hidden">Please select a title</p>
+           </div>
+           <div>
+                <label for="dob">Birthday</label>
+                <em>:</em>
+                <select id="dobdd" name="dobdd">
+                    <option value="1">1</option>
+                    <option value="2">2</option>
+                </select>
+                <select id="dobmm" name="dobmm">
+                    <option value="1">Jan</option>
+                    <option value="2">Feb</option>
+                </select>
+                <select id="dobyy" name="dobyy">
+                    <option value="1980">1980</option>
+                    <option value="1981">1981</option>
+                </select>
+                <p class="errorfield hidden">Invalid date</p>
+           </div>
+           <div>
+                <input type="submit" value="Submit Form" id="submit" name="submit">
+           </div>
        </fieldset>
-	</form>
+    </form>
 
 =head2 How to create a form with validation
 
